@@ -1,5 +1,5 @@
 mod vis_mod {
-    use builder_pattern::*;
+    use builder_pattern::Builder;
 
     #[allow(dead_code)]
     #[derive(Debug)]
@@ -25,6 +25,7 @@ mod vis_mod {
     pub struct PublicTest {
         pub a: i32,
         #[default(String::from(""))]
+        #[into]
         pub b: String,
         #[default(Some(3))]
         pub c: Option<i32>,
